@@ -498,9 +498,9 @@ GEN hnf(GEN x)
 
   if(typ(x)!=19) err(hnfer1);
   lim=(avma+bot)>>1;
-  av0=avma;denx=denom(x);
-  av=avma;co=lg(x);li=lg((GEN)x[1]);
-  y=gcmp1(denx)?gcopy(x):gmul(denx,x);
+  co=lg(x);if(co==1) return gcopy(x);
+  li=lg((GEN)x[1]);av0=avma;denx=denom(x);
+  av=avma;y=gcmp1(denx)?gcopy(x):gmul(denx,x);
   def=co;ldef=(li>co)?li-co+1:1;
   for(i=li-1;i>=ldef;i--)
     {
@@ -699,7 +699,8 @@ GEN hnfhavas(GEN x)
   GEN p1,p2,p3,p12,p13,y,z,u,d,denx,vperm,mat1,col2,lil2,s,pmin,apro,bpro,cpro;
 
   if(typ(x)!=19) err(hnfer1);
-  av0=avma;denx=denom(x);co=lg(x);li=lg((GEN)x[1]);
+  av0=avma;co=lg(x);if(co==1) return gcopy(x);
+  li=lg((GEN)x[1]);denx=denom(x);
   vperm=cgeti(li);for(i=1;i<li;i++) vperm[i]=i;
   lim=(avma+bot)>>1;av=avma;u=idmat(co-1);
   y=gcmp1(denx)?gcopy(x):gmul(denx,x);def=co;ldef=(li>co)?li-co+1:1;
