@@ -993,7 +993,7 @@ GEN apell(GEN e, GEN pl)
   if(divise((GEN)e[12],pl)) return stoi(((((pl[lgef(pl)-1]&3)+1)&2)-1)*kronecker((GEN)e[11],pl));
   if (gcmpgs(pl, 0x3fffffff) > 0) return apell1(e, pl);
   p = itos(pl);
-  if (p < 100) return apell2(e, pl);
+  if (p <= 457) return apell2(e, pl);
   unmodp = gmodulcp(gun, pl);
   c4 = itos((GEN)gdivgs(gmul(unmodp,(GEN)e[10]), -48)[2]);
   c6 = itos((GEN)gdivgs(gmul(unmodp,(GEN)e[11]), -864)[2]);
